#ifndef LIBKYAPPLICATIONSEC_H
#define LIBKYAPPLICATIONSEC_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 设置应用包中所有程序均可联网
 * @param pkgname[in] 包名
 * @return int 返回0表示成功，返回非零表示失败
 */
int kdk_set_app_can_net(const char* pkgname);

/**
 * @brief 设置应用包中所有程序均不可联网
 * @param pkgname[in] 包名
 * @return int 返回0表示成功，返回非零表示失败
 */
int kdk_clear_app_can_net(const char* pkgname);

/**
 * @brief 设置应用包中所有程序均可执行
 * @param pkgname[in] 包名
 * @return int 返回0表示成功，返回非零表示失败
 */
int kdk_set_app_can_exec(const char* pkgname);

/**
 * @brief 设置应用包中所有程序均可不执行
 * @param pkgname[in] 包名
 * @return int 返回0表示成功，返回非零表示失败
 */
int kdk_clear_app_can_exec(const char* pkgname);

typedef enum app_type {
    APP_NULL,
    APP_KYLIN_PRINTER, //麒麟打印
    APP_KYLIN_BURNER, //麒麟刻录
    APP_END
} app_type;

/**
 * @brief 设置应用审计日志状态
 * 
 * @param apptype 应用类型 app_type 
 * @param status 0 关闭,1开启 
 * @return int 返回0表示成功，返回非零表示失败
 */
int kdk_set_app_audit_status(int apptype, int status);

/**
 * @brief 获取应用审计日志状态
 * 
 * @param apptype 应用类型 app_type
 * @return int 0 关闭,1开启，其他表示获取失败
 */
int kdk_get_app_audit_status(int apptype);


/**
 * @brief 添加软件包到应用防卸载 
 * 如果系统支持软件包防卸载黑白名单模式会自动开启黑名单模式,并将software加入黑名单
 * 
 * @param software 包名 
 * @return int 
 *         0：成功
 *        -1：出错 
 *         1：重复添加
 * 
 */
int kdk_software_set_anti_uninstall(const char *software);

/**
 * @brief 取消软件包应用防卸载
 * 如果系统支持软件包防卸载黑白名单模式会自动开启黑名单模式,并将software剔除黑名单
 * 
 * @param software 包名 
 * @return int 
 *         0：成功
 *        -1：出错
 *         1：不存在
 */
int kdk_software_clear_anti_uninstall(const char *software);

#ifdef __cplusplus
}
#endif

#endif // LIBKYAPPLICATIONSEC_H
